@@ -1,15 +1,17 @@
 import logging
 import subprocess
-from typing import List
+from pathlib import Path
+from typing import List, Optional, Union
 
 logger = logging.getLogger(__name__)
 
 
-def run_in_subprocess(command: List[str]) -> str:
+def run_in_subprocess(command: List[str], working_directory: Optional[Union[str, Path]] = None) -> str:
     process = subprocess.run(
         command,
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
+        cwd=working_directory,
     )
 
     stdout = process.stdout.decode()
